@@ -4,15 +4,17 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.03';
+$VERSION = '0.05';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000009-000003"; }
+sub IDENTIFICATION { return "000001-000009-000005"; }
 
 sub preference { return 1000; }
 
+sub known_actions { return [ qw/COMMAND/ ]; }
+
 sub handle_action {
 	my ($obj,%action) = @_;
 
@@ -21,6 +23,9 @@ sub handle_action {
 			$action{action} = 'HELP';
 			$action{type} = 'commands';
 			$action{what} = $1;
+		} elsif ($action{cmd} =~ /^show\s+versions?$/i) {
+			$action{action} = 'HELP';
+			$action{type} = 'version';
 		}
 	}
 
@@ -30,12 +35,14 @@ sub handle_action {
 
 sub cmdhelp {
 	return [
-		'HELP' => 'Show this help'
+		'HELP' => 'Show this help',
+		'SHOW VERSION' => 'Show dbMan'."'".'s version'
 	];
 }
 
 sub cmdcomplete {
 	my ($obj,$text,$line,$start) = @_;
-	return qw/HELP/ if $line =~ /^\s*[A-Z]*$/i;
+	return qw/VERSION/ if $line =~ /^\s*SHOW\s+[A-Z]*$/i;
+	return qw/HELP SHOW/ if $line =~ /^\s*[A-Z]*$/i;
 	return ();
 }
